@@ -5,6 +5,7 @@ from moneyed import Money, Currency, DEFAULT_CURRENCY
 from djmoney import forms
 
 from decimal import Decimal
+import inspect
 
 __all__ = ('MoneyField', 'currency_field_name', 'NotSupportedLookup')
 
@@ -74,6 +75,10 @@ class MoneyField(models.DecimalField):
 
         if isinstance(default, Money):
             self.default_currency = default.currency
+        else:
+            self.default_currency = default_currency
+            # To ultimately pass default_currency on to widget
+            default = Money(default, default_currency)
 
         # Avoid giving the user hard-to-debug errors if they miss required attributes
         if max_digits is None:
@@ -82,7 +87,6 @@ class MoneyField(models.DecimalField):
         if decimal_places is None:
             raise Exception("You have to provide a decimal_places attribute to Money fields.")
 
-        self.default_currency = default_currency
         super(MoneyField, self).__init__(verbose_name, name, max_digits, decimal_places, default=default, **kwargs)
 
     def to_python(self, value):
@@ -117,6 +121,7 @@ class MoneyField(models.DecimalField):
     def get_db_prep_save(self, value, connection):
         if isinstance(value, Money):
             value = value.amount
+            return value
         return super(MoneyField, self).get_db_prep_save(value, connection)
 
     def get_db_prep_lookup(self, lookup_type, value, connection, prepared=False):
@@ -127,6 +132,11 @@ class MoneyField(models.DecimalField):
 
     def get_default(self):
         if isinstance(self.default, Money):
+            frm = inspect.stack()[1]
+            mod = inspect.getmodule(frm[0])
+            # We need to return the numerical value if this is called by south
+            if mod.__name__ == "south.db.generic":
+                return float(self.default.amount)
             return self.default
         else:
             return super(MoneyField, self).get_default()
@@ -139,25 +149,32 @@ class MoneyField(models.DecimalField):
     def value_to_string(self, obj):
         return obj.__dict__[self.attname].amount
 
+    def south_field_triple(self):
+        "Returns a suitable description of this field for South."
+        # Note: This method gets automatically with schemamigration time.
+        from south.modelsinspector import introspector
+        field_class = self.__class__.__module__ + "." + self.__class__.__name__
+        args, kwargs = introspector(self)
+        # We need to
+        # 1. Delete the default, 'cause it's not automatically supported.
+        kwargs.pop('default')
+        # 2. add the default currency, because it's not picked up from the inspector automatically.
+        kwargs['default_currency'] = "'%s'" % self.default_currency
+        return (field_class, args, kwargs)
+
 
 ## South support
 try:
     from south.modelsinspector import add_introspection_rules
-
     rules = [
-        ((MoneyField,),
-         [],  # No positional args
-         {'default': ('default', {'default': Decimal('0.0')}),
-         'default_currency': ('default_currency', {'default': DEFAULT_CURRENCY}),
-          "frozen_by_south": [True, {"is_value": True}]
-          }),
+        # MoneyField has its own method.
         ((CurrencyField,),
          [],  # No positional args
          {'default': ('default', {'default': DEFAULT_CURRENCY.code}),
           'max_length': ('max_length', {'default': 3})}),
     ]
 
-    add_introspection_rules(rules, ["^djmoney\.models\.fields\.MoneyField",
-                                    "^djmoney\.models\.fields\.CurrencyField"])
+    # MoneyField implement the serialization in south_field_triple method
+    add_introspection_rules(rules, ["^djmoney\.models\.fields\.CurrencyField"])
 except ImportError:
     pass
